@@ -1,5 +1,60 @@
 package Workflow::Condition::LazyAND;
 
+# $Id: LazyAND.pm 581 2012-11-10 13:42:38Z jonasbn $
+
+use strict;
+use warnings;
+
+our $VERSION = '1.0';
+
+use base qw( Workflow::Condition::Nested );
+use Workflow::Exception qw( condition_error configuration_error );
+use English qw( -no_match_vars );
+
+__PACKAGE__->mk_accessors('conditions');
+
+my ($log);
+
+sub _init {
+    my ( $self, $params ) = @_;
+
+    # This is a tricky one. The admin may have configured this by repeating
+    # the param name "condition" or by using unique names (e.g.: "condition1",
+    # "condition2", etc.). We'll need to string these back together as
+    # an array.
+    # Yes, I know. The regex doesn't require the suffix to be numeric.
+    my @conditions = ();
+    foreach my $key ( sort grep {m/^condition/} keys %{$params} ) {
+        push @conditions, $self->normalize_array( $params->{$key} );
+    }
+    $self->conditions( [@conditions] );
+
+}
+
+sub evaluate {
+    my ( $self, $wf ) = @_;
+    my $conditions = $self->conditions;
+
+    my $total = 0;
+
+    foreach my $cond ( @{$conditions} ) {
+        my $result = $self->evaluate_condition( $wf, $cond );
+        if ( not $result ) {
+            condition_error("Condition '$cond' returned 'false'");
+        }
+        $total += $result;
+    }
+
+    return $total
+        || condition_error("No condition seems to have been run in LazyAND");
+}
+
+1;
+
+__END__
+
+=pod
+
 =head1 NAME
 
 Workflow::Condition::LazyAND
@@ -56,50 +111,13 @@ E<or>
     <param name="condition1" value="first_condition_to_test" />
     <param name="condition2" value="second_condition_to_test" />
 
+=head1 AUTHORS
+
+See L<Workflow>
+
+=head1 COPYRIGHT
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
-
-use strict;
-use warnings;
-
-use base qw( Workflow::Condition::Nested );
-use Workflow::Exception qw( condition_error configuration_error );
-use English qw( -no_match_vars );
-
-__PACKAGE__->mk_accessors('conditions');
-
-my ($log);
-
-sub _init {
-    my ( $self, $params ) = @_;
-
-    # This is a tricky one. The admin may have configured this by repeating
-    # the param name "condition" or by using unique names (e.g.: "condition1",
-    # "condition2", etc.). We'll need to string these back together as
-    # an array.
-    # Yes, I know. The regex doesn't require the suffix to be numeric.
-    my @conditions = ();
-    foreach my $key ( sort grep {m/^condition/} keys %{$params} ) {
-        push @conditions, $self->normalize_array( $params->{$key} );
-    }
-    $self->conditions( [@conditions] );
-
-}
-
-sub evaluate {
-    my ( $self, $wf ) = @_;
-    my $conditions = $self->conditions;
-
-    my $total = 0;
-
-    foreach my $cond ( @{$conditions} ) {
-        my $result = $self->evaluate_condition( $wf, $cond );
-        if ( not $result ) {
-            condition_error( "Condition '$cond' returned 'false'" );
-        }
-        $total += $result;
-    }
-
-    return $total || condition_error( "No condition seems to have been run in LazyAND" );
-}
-
-1;
